summaryrefslogtreecommitdiff
path: root/chromium/third_party/blink/renderer/modules/webdatabase/database_context.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/blink/renderer/modules/webdatabase/database_context.h')
-rw-r--r--chromium/third_party/blink/renderer/modules/webdatabase/database_context.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/chromium/third_party/blink/renderer/modules/webdatabase/database_context.h b/chromium/third_party/blink/renderer/modules/webdatabase/database_context.h
index cb56a462f5d..ec86707519d 100644
--- a/chromium/third_party/blink/renderer/modules/webdatabase/database_context.h
+++ b/chromium/third_party/blink/renderer/modules/webdatabase/database_context.h
@@ -28,7 +28,7 @@
#ifndef THIRD_PARTY_BLINK_RENDERER_MODULES_WEBDATABASE_DATABASE_CONTEXT_H_
#define THIRD_PARTY_BLINK_RENDERER_MODULES_WEBDATABASE_DATABASE_CONTEXT_H_
-#include "third_party/blink/renderer/core/execution_context/context_lifecycle_observer.h"
+#include "third_party/blink/renderer/core/execution_context/execution_context_lifecycle_observer.h"
#include "third_party/blink/renderer/platform/heap/handle.h"
namespace blink {
@@ -39,7 +39,7 @@ class ExecutionContext;
class SecurityOrigin;
class DatabaseContext final : public GarbageCollected<DatabaseContext>,
- public ContextLifecycleObserver {
+ public ExecutionContextLifecycleObserver {
USING_GARBAGE_COLLECTED_MIXIN(DatabaseContext);
public:
@@ -49,10 +49,11 @@ class DatabaseContext final : public GarbageCollected<DatabaseContext>,
explicit DatabaseContext(ExecutionContext*);
~DatabaseContext();
- void Trace(blink::Visitor*) override;
+ void Trace(Visitor*) override;
- // For life-cycle management (inherited from ContextLifecycleObserver):
- void ContextDestroyed(ExecutionContext*) override;
+ // For life-cycle management (inherited from
+ // ExecutionContextLifecycleObserver):
+ void ContextDestroyed() override;
DatabaseContext* Backend();
DatabaseThread* GetDatabaseThread();